==> jc-1.4.0.tar.gz: javax/crypto/BadPaddingException.h <==
// public class javax.crypto.BadPaddingException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class d214adbc7b3842af javax_crypto_BadPaddingException

// header file dependencies
// @dep_header java_security_GeneralSecurityException

#include "java/security/GeneralSecurityException.h"

#ifndef _JC_javax_crypto_BadPaddingException_H_
#define _JC_javax_crypto_BadPaddingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_crypto_BadPaddingException$sub_refs	_jc_javax_crypto_BadPaddingException$sub_refs;
typedef struct _jc_javax_crypto_BadPaddingException$sub_nonrefs	_jc_javax_crypto_BadPaddingException$sub_nonrefs;
typedef struct _jc_javax_crypto_BadPaddingException$refs	_jc_javax_crypto_BadPaddingException$refs;
typedef struct _jc_javax_crypto_BadPaddingException$nonrefs	_jc_javax_crypto_BadPaddingException$nonrefs;
typedef struct _jc_javax_crypto_BadPaddingException$object	_jc_javax_crypto_BadPaddingException$object;

typedef struct _jc_javax_crypto_BadPaddingException$fields_struct	_jc_javax_crypto_BadPaddingException$fields_struct;
typedef const struct _jc_javax_crypto_BadPaddingException$vmethods	_jc_javax_crypto_BadPaddingException$vmethods;
typedef const struct _jc_javax_crypto_BadPaddingException$vtable	_jc_javax_crypto_BadPaddingException$vtable;
typedef const struct _jc_javax_crypto_BadPaddingException$vtype	_jc_javax_crypto_BadPaddingException$vtype;

// Class fields structure
struct _jc_javax_crypto_BadPaddingException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_crypto_BadPaddingException$fields_struct _jc_javax_crypto_BadPaddingException$class_fields;

// Constructors
extern void _jc_javax_crypto_BadPaddingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_BadPaddingException$object *);
extern void _jc_javax_crypto_BadPaddingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_crypto_BadPaddingException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_crypto_BadPaddingException$vmethods {
};

// Vtable
struct _jc_javax_crypto_BadPaddingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_javax_crypto_BadPaddingException$vmethods	javax_crypto_BadPaddingException;
};

// Vtype
struct _jc_javax_crypto_BadPaddingException$vtype {
	_jc_type			type;
	_jc_javax_crypto_BadPaddingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_BadPaddingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_BadPaddingException$refs {
    _jc_javax_crypto_BadPaddingException$sub_refs	javax_crypto_BadPaddingException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_BadPaddingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_BadPaddingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_javax_crypto_BadPaddingException$sub_nonrefs	javax_crypto_BadPaddingException;
};

// Object instance structure
struct _jc_javax_crypto_BadPaddingException$object {
	_jc_javax_crypto_BadPaddingException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_BadPaddingException$vtype	*vtype;
	_jc_javax_crypto_BadPaddingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_BadPaddingException$vtype _jc_javax_crypto_BadPaddingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_BadPaddingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_BadPaddingException$class_object;

#endif	/* _JC_javax_crypto_BadPaddingException_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/BadPaddingException.h <==
// public class javax.crypto.BadPaddingException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 692089051f4c8d0b java_security_GeneralSecurityException
// @dep_class d214adbc7b3842af javax_crypto_BadPaddingException

// header file dependencies
// @dep_header java_security_GeneralSecurityException

#include "java/security/GeneralSecurityException.h"

#ifndef _JC_javax_crypto_BadPaddingException_H_
#define _JC_javax_crypto_BadPaddingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_crypto_BadPaddingException$sub_refs	_jc_javax_crypto_BadPaddingException$sub_refs;
typedef struct _jc_javax_crypto_BadPaddingException$sub_nonrefs	_jc_javax_crypto_BadPaddingException$sub_nonrefs;
typedef struct _jc_javax_crypto_BadPaddingException$refs	_jc_javax_crypto_BadPaddingException$refs;
typedef struct _jc_javax_crypto_BadPaddingException$nonrefs	_jc_javax_crypto_BadPaddingException$nonrefs;
typedef struct _jc_javax_crypto_BadPaddingException$object	_jc_javax_crypto_BadPaddingException$object;

typedef struct _jc_javax_crypto_BadPaddingException$fields_struct	_jc_javax_crypto_BadPaddingException$fields_struct;
typedef const struct _jc_javax_crypto_BadPaddingException$vmethods	_jc_javax_crypto_BadPaddingException$vmethods;
typedef const struct _jc_javax_crypto_BadPaddingException$vtable	_jc_javax_crypto_BadPaddingException$vtable;
typedef const struct _jc_javax_crypto_BadPaddingException$vtype	_jc_javax_crypto_BadPaddingException$vtype;

// Class fields structure
struct _jc_javax_crypto_BadPaddingException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_crypto_BadPaddingException$fields_struct _jc_javax_crypto_BadPaddingException$class_fields;

// Constructors
extern void _jc_javax_crypto_BadPaddingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_BadPaddingException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_BadPaddingException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_crypto_BadPaddingException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_crypto_BadPaddingException$vmethods {
};

// Vtable
struct _jc_javax_crypto_BadPaddingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_security_GeneralSecurityException$vmethods	java_security_GeneralSecurityException;
	_jc_javax_crypto_BadPaddingException$vmethods	javax_crypto_BadPaddingException;
};

// Vtype
struct _jc_javax_crypto_BadPaddingException$vtype {
	_jc_type			type;
	_jc_javax_crypto_BadPaddingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_BadPaddingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_BadPaddingException$refs {
    _jc_javax_crypto_BadPaddingException$sub_refs	javax_crypto_BadPaddingException;
    _jc_java_security_GeneralSecurityException$sub_refs	java_security_GeneralSecurityException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_BadPaddingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_BadPaddingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_security_GeneralSecurityException$sub_nonrefs	java_security_GeneralSecurityException;
    _jc_javax_crypto_BadPaddingException$sub_nonrefs	javax_crypto_BadPaddingException;
};

// Object instance structure
struct _jc_javax_crypto_BadPaddingException$object {
	_jc_javax_crypto_BadPaddingException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_BadPaddingException$vtype	*vtype;
	_jc_javax_crypto_BadPaddingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_BadPaddingException$vtype _jc_javax_crypto_BadPaddingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_BadPaddingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_BadPaddingException$class_object;

#endif	/* _JC_javax_crypto_BadPaddingException_H_ */
